#include <Servo.h>

Servo myServo;

int switchPins[] = {3, 4, 5, 6}; //Dip Switch pins
int code[] = {1, 0, 1, 0}; //Code

int green = 2; //Green LED
int red = A2; //Red LED

//7-Segment Pins
int a = 11;
int b = 10; 
int c = 9;
int d = 8; 
int e = 7;
int f = 12; 
int g = 13;

void setup()             {
  myServo.attach(A1); //Servo pin

  for (int i = 0; i < 4; i++)
  {
    pinMode(switchPins[i], INPUT); //Dip Switch pins as input
  }

  for (int i = 7; i < 14; i++)
  {
    pinMode(i, OUTPUT); //7-Segment pins as output
  }

  pinMode(green, OUTPUT); //Green LED as output
  pinMode(red, OUTPUT); //Red LED as output

  //Starts as red
  digitalWrite(green, LOW);
  digitalWrite(red, HIGH);

  myServo.write(50); //Servo is closed

  Serial.begin(9600);
}

void loop() {
  checkCode(); //Function call to check the code and perform the actions accordingly
}

void checkCode() {
  int inputCode[] = {digitalRead(switchPins[0]), digitalRead(switchPins[1]), digitalRead(switchPins[2]), digitalRead(switchPins[3])}; //Reads the current code on the dip switch

  //If codes math
  bool codeMatch = true; //Codes are matching
  for (int i = 0; i < 4; i++)
  {
    //If any of the codes are different
    if (inputCode[i] != code[i])
    {
      codeMatch = false; //Codes are not matching
      break;
    }
  }

  //If the codes match
  if (codeMatch)
  {
    digitalWrite(green, HIGH); //Green LED is on
    myServo.write(140); //Sets servo to open door
    digitalWrite(red, LOW); //Red LED is off

    //Display 5-second countdown before door closes
    five();
    delay(1000);
    four();
    delay(1000);
    three();
    delay(1000);
    two();
    delay(1000);
    one();
    delay(1000);
    zero();
    
    myServo.write(50); //Sets servo to close door
    digitalWrite(green, LOW); //Green LED is off
    delay(500); //Short delay to stabilize
    digitalWrite(red, HIGH); //Red LED is on
  }
  else
  {
    digitalWrite(green, LOW); //Green LED is off
    digitalWrite(red, HIGH); //Red LED is on

    dash(); //Dash show on 7-segment while code is being run
    delay(100); //Short delay to avoid rapidness
  }
}

void five() {
  //Shows the number 5 on the display
  digitalWrite(a, LOW);
  digitalWrite(b, HIGH);
  digitalWrite(c, LOW);
  digitalWrite(d, LOW);
  digitalWrite(e, HIGH);
  digitalWrite(f, LOW);
  digitalWrite(g, LOW);
  }

void four() {
  //Shows the number 4 on the display
  digitalWrite(a, HIGH);
  digitalWrite(b, LOW);
  digitalWrite(c, LOW);
  digitalWrite(d, HIGH);
  digitalWrite(e, HIGH);
  digitalWrite(f, LOW);
  digitalWrite(g, LOW);
  }

void three() {
  //Shows the number 3 on the display
  digitalWrite(a, LOW);
  digitalWrite(b, LOW);
  digitalWrite(c, LOW);
  digitalWrite(d, LOW);
  digitalWrite(e, HIGH);
  digitalWrite(f, HIGH);
  digitalWrite(g, LOW);
  }

void two() {
  //Shows the number 2 on the display
  digitalWrite(a, LOW);
  digitalWrite(b, LOW);
  digitalWrite(c, HIGH);
  digitalWrite(d, LOW);
  digitalWrite(e, LOW);
  digitalWrite(f, HIGH);
  digitalWrite(g, LOW);
  }

void one() {
  //Shows the number 1 on the display
  digitalWrite(a, HIGH);
  digitalWrite(b, LOW);
  digitalWrite(c, LOW);
  digitalWrite(d, HIGH);
  digitalWrite(e, HIGH);
  digitalWrite(f, HIGH);
  digitalWrite(g, HIGH);
  }

void zero() {
  //Shows a zero on the display
  digitalWrite(a, LOW);
  digitalWrite(b, LOW);
  digitalWrite(c, LOW);
  digitalWrite(d, LOW);
  digitalWrite(e, LOW);
  digitalWrite(f, LOW);
  digitalWrite(g, HIGH);
  }

void dash() {
  //Shows a dash  on the display
  digitalWrite(a, HIGH);
  digitalWrite(b, HIGH);
  digitalWrite(c, HIGH);
  digitalWrite(d, HIGH);
  digitalWrite(e, HIGH);
  digitalWrite(f, HIGH);
  digitalWrite(g, LOW);
  }
